@@ -1,11 +1,7 @@
 package HTTP::Throwable::Role::Status::BadRequest;
-BEGIN {
-  $HTTP::Throwable::Role::Status::BadRequest::AUTHORITY = 'cpan:STEVAN';
-}
-{
-  $HTTP::Throwable::Role::Status::BadRequest::VERSION = '0.017';
-}
-use Moose::Role;
+our $AUTHORITY = 'cpan:STEVAN';
+$HTTP::Throwable::Role::Status::BadRequest::VERSION = '0.026';
+use Moo::Role;
 
 with(
     'HTTP::Throwable',
@@ -16,17 +12,19 @@ sub default_status_code { 400 }
 
 sub default_reason { 'Bad Request' }
 
-no Moose::Role; 1;
+no Moo::Role; 1;
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 HTTP::Throwable::Role::Status::BadRequest - 400 Bad Request
 
 =head1 VERSION
 
-version 0.017
+version 0.026
 
 =head1 DESCRIPTION
 
@@ -61,3 +59,8 @@ __END__
 
 # ABSTRACT: 400 Bad Request
 
+#pod =head1 DESCRIPTION
+#pod
+#pod The request could not be understood by the server due to
+#pod malformed syntax. The client SHOULD NOT repeat the request
+#pod without modifications.
