@@ -1,11 +1,7 @@
 package HTTP::Throwable::Role::Status::LengthRequired;
-BEGIN {
-  $HTTP::Throwable::Role::Status::LengthRequired::AUTHORITY = 'cpan:STEVAN';
-}
-{
-  $HTTP::Throwable::Role::Status::LengthRequired::VERSION = '0.018';
-}
-use Moose::Role;
+our $AUTHORITY = 'cpan:STEVAN';
+$HTTP::Throwable::Role::Status::LengthRequired::VERSION = '0.026';
+use Moo::Role;
 
 with(
     'HTTP::Throwable',
@@ -15,17 +11,19 @@ with(
 sub default_status_code { 411 }
 sub default_reason      { 'Length Required' }
 
-no Moose::Role; 1;
+no Moo::Role; 1;
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 HTTP::Throwable::Role::Status::LengthRequired - 411 Length Required
 
 =head1 VERSION
 
-version 0.018
+version 0.026
 
 =head1 DESCRIPTION
 
@@ -61,3 +59,9 @@ __END__
 
 # ABSTRACT: 411 Length Required
 
+#pod =head1 DESCRIPTION
+#pod
+#pod The server refuses to accept the request without a defined
+#pod Content-Length. The client MAY repeat the request if it
+#pod adds a valid Content-Length header field containing the
+#pod length of the message-body in the request message.
