@@ -1,11 +1,7 @@
 package HTTP::Throwable::Role::Status::UnsupportedMediaType;
-BEGIN {
-  $HTTP::Throwable::Role::Status::UnsupportedMediaType::AUTHORITY = 'cpan:STEVAN';
-}
-{
-  $HTTP::Throwable::Role::Status::UnsupportedMediaType::VERSION = '0.017';
-}
-use Moose::Role;
+our $AUTHORITY = 'cpan:STEVAN';
+$HTTP::Throwable::Role::Status::UnsupportedMediaType::VERSION = '0.026';
+use Moo::Role;
 
 with(
     'HTTP::Throwable',
@@ -15,17 +11,19 @@ with(
 sub default_status_code { 415 }
 sub default_reason      { 'Unsupported Media Type' }
 
-no Moose::Role; 1;
+no Moo::Role; 1;
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 HTTP::Throwable::Role::Status::UnsupportedMediaType - 415 Unsupported Media Type
 
 =head1 VERSION
 
-version 0.017
+version 0.026
 
 =head1 DESCRIPTION
 
@@ -60,3 +58,9 @@ __END__
 
 # ABSTRACT: 415 Unsupported Media Type
 
+#pod =head1 DESCRIPTION
+#pod
+#pod The server is refusing to service the request because the entity
+#pod of the request is in a format not supported by the requested resource
+#pod for the requested method.
+#pod
